ManifoldContext<M, T> class

Constructors

ManifoldContext({required BuildContext buildContext, required ManifoldProvider<M> provider, required ArtifactFieldMirror field, required Property? property, required T? value, required ValueChanged<T?> onChanged, required bool readOnly, List<ManifoldValidator> validators = const <ManifoldValidator>[]})

Properties

buildContext BuildContext
final
field → ArtifactFieldMirror
final
hashCode int
The hash code for this object.
no setterinherited
onChanged ValueChanged<T?>
final
property Property?
final
provider ManifoldProvider<M>
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validators List<ManifoldValidator>
final
value → T?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited