ManifoldDecoratorContext class
Constructors
-
ManifoldDecoratorContext({required BuildContext buildContext, required ArtifactFieldMirror field, required Property? property, required dynamic value, required Widget editor, required bool readOnly, List<
String> validationErrors = const <String>[]}) -
const
Properties
- buildContext → BuildContext
-
final
- editor → Widget
-
final
- field → ArtifactFieldMirror
-
final
- firstValidationError → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasValidationErrors → bool
-
no setter
- icon → IconData
-
no setter
- inline → bool
-
no setter
- label → String
-
no setter
- property → Property?
-
final
- readOnly → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
validationErrors
→ List<
String> -
final
- value → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited