ManifoldProvider<T> class

Constructors

ManifoldProvider(BehaviorSubject<T> value, $AClass<T> mirror, {bool readOnly = false})

Properties

fields Iterable<($AFld, Stream<ArtifactFieldMirror>)>
no setter
fireCrudDocumentPath String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mirror → $AClass<T>
final
readOnly bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → BehaviorSubject<T>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
push(T instance) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of<T>(BehaviorSubject<T> subject, {bool readOnly = false}) ManifoldProvider<T>