MapTypeInfo class
Constructors
- MapTypeInfo({required $AT typeDescriptor, required $AT keyTypeDescriptor, required $AT valueTypeDescriptor, required bool nullableMap, required bool nullableKey, required bool nullableValue})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyDisplayType → String
-
no setter
- keyTypeDescriptor → $AT
-
final
- nullableKey → bool
-
final
- nullableMap → bool
-
final
- nullableValue → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeDescriptor → $AT
-
final
- valueDisplayType → String
-
no setter
- valueTypeDescriptor → $AT
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited