Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCollectionStyle<M, T>({required ManifoldEditorScope<M> scope, required $AFld field, required Iterable<T>? value})
→ ManifoldContainerType
-
-
getMapStyle<M, K, V>({required ManifoldEditorScope<M> scope, required $AFld field, required Map<K, V>? value})
→ ManifoldContainerType
-
-
getSubObjectStyle<M, O>({required ManifoldEditorScope<M> scope, required $AFld field, required O? value})
→ ManifoldContainerType
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited